diff --git a/source/config/__init__.py b/source/config/__init__.py
index c02396d..b88db72 100644
--- a/source/config/__init__.py
+++ b/source/config/__init__.py
@@ -191,6 +191,7 @@ confspec = ConfigObj(StringIO(
 
 [update]
 	autoCheck = boolean(default=true)
+	reportStatistics = boolean(default=true)
 
 [inputComposition]
 	autoReportAllCandidates = boolean(default=True)
diff --git a/source/gui/settingsDialogs.py b/source/gui/settingsDialogs.py
index c833bf0..86012ea 100644
--- a/source/gui/settingsDialogs.py
+++ b/source/gui/settingsDialogs.py
@@ -199,6 +199,13 @@ class GeneralSettingsDialog(SettingsDialog):
 			if globalVars.appArgs.secure:
 				item.Disable()
 			settingsSizer.Add(item)
+			# Translators: The label of a checkbox in general settings to toggle reporting of statistical information for NVDA usage to NVAccess.
+			item=self.reportStatisticsCheckBox=wx.CheckBox(self,label=_("Allow sending anonymous &statistical information to NVAccess"))
+			item.Value=config.conf["update"]["reportStatistics"]
+			self.Bind(wx.EVT_UPDATE_UI, self.onChangeUpdateCheckEVT, item)
+			if globalVars.appArgs.secure:
+				item.Disable()
+			settingsSizer.Add(item)
 
 	def postInit(self):
 		self.languageList.SetFocus()
@@ -247,6 +254,13 @@ class GeneralSettingsDialog(SettingsDialog):
 			# Translators: The message displayed when copying configuration to system settings was successful.
 			gui.messageBox(_("Successfully copied NVDA user settings"),_("Success"),wx.OK|wx.ICON_INFORMATION,self)
 
+	def onChangeUpdateCheckEVT(self, evt):
+		if self.autoCheckForUpdatesCheckBox.IsChecked():
+			evt.Check(True)
+			evt.Enable(False)
+		else:
+			evt.Enable(True)
+
 	def onOk(self,evt):
 		newLanguage=[x[0] for x in self.languageNames][self.languageList.GetSelection()]
 		if newLanguage!=self.oldLanguage:
@@ -272,6 +286,7 @@ class GeneralSettingsDialog(SettingsDialog):
 				gui.messageBox(_("This change requires administrator privileges."), _("Insufficient Privileges"), style=wx.OK | wx.ICON_ERROR, parent=self)
 		if updateCheck:
 			config.conf["update"]["autoCheck"]=self.autoCheckForUpdatesCheckBox.IsChecked()
+			config.conf["update"]["reportStatistics"]=self.reportStatisticsCheckBox.IsChecked()
 			updateCheck.terminate()
 			updateCheck.initialize()
 		if self.oldLanguage!=newLanguage:
diff --git a/source/updateCheck.py b/source/updateCheck.py
index 7993e9f..12cd5bb 100644
--- a/source/updateCheck.py
+++ b/source/updateCheck.py
@@ -169,6 +169,8 @@ class AutoUpdateChecker(UpdateChecker):
 			return
 		if info["version"] == state["dontRemindVersion"]:
 			return
+		if not config.conf["update"]["autoCheck"]:
+			return
 		wx.CallAfter(UpdateResultDialog, gui.mainFrame, info, True)
 
 class UpdateResultDialog(wx.Dialog):
@@ -447,7 +449,7 @@ def initialize():
 	except (KeyError, OSError):
 		pass
 
-	if config.conf["update"]["autoCheck"] and not globalVars.appArgs.launcher:
+	if config.conf["update"]["reportStatistics"] and not globalVars.appArgs.launcher:
 		autoChecker = AutoUpdateChecker()
 
 def terminate():
diff --git a/user_docs/en/userGuide.t2t b/user_docs/en/userGuide.t2t
index 0560398..bc226d0 100644
--- a/user_docs/en/userGuide.t2t
+++ b/user_docs/en/userGuide.t2t
@@ -620,6 +620,24 @@ This option is only available for installed copies of NVDA.
 If this is enabled, NVDA will automatically check for updated versions of NVDA and inform you when an update is available.
 You can also manually check for updates by selecting Check for updates under Help in the NVDA menu.
 
+When checking for updates, NVDA also sends some anonymous statistics about the system (see the next option).
+You can disable automatic checking of updates and still participate in the gathering of statistical data, but not vice versa.
+
+==== Allow sending anonymous statistical information to NVAccess ====
+If this checkbox is checked, NVDA will continue sending statistical information about dayly usage, despite that automatic checking for updates is turned off.
+If automatic checking for updates is on, this option will be also on and the checkbox will be disabled.
+This allows the developers to understand some usage patterns, which could be useful in some situations when an important decision should be made.
+Those statistics are also useful to the different sponsors in the different regions of the world.
+
+Gathered statistics are the following:
+- NVDA version, wether this is a portable or an installed copy and wether it is a dayly snapshot, beta or stable version.
+- Windows version, including the build number, the service pack number (if any) and wether it is a 32 or 64 bit.
+- The NVDA language been used.
+- The type of the current update check, i.e. automatic or manual.
+-
+
+You can see some of the statistics on [NVDA community site http://community.nvda-project.org/usersByCountry.html].
+
 +++ Synthesizer Selection (NVDA+control+s) +++
 The Synthesizer dialog, which is found under "Synthesizer..." in the Preferences menu, allows you to select which Synthesizer NVDA should use to speak with.
 Once you have selected your synthesizer of choice, you can press Ok and NVDA will load the selected Synthesizer.
